pub type DQuadSource<'a, D> = Box<dyn Iterator<Item = DResult<D, <D as Dataset>::Quad<'a>>> + 'a>;๐Deprecated since 0.8.1:
prototypes of quads and quads_matching have changed
Type alias for fallible quad iterators produced by a dataset.
See Dataset::quads for more information about how to use it.
Aliased Type
pub struct DQuadSource<'a, D>(/* private fields */);